import { __decorate, __param } from 'tslib';
import { Optional, Injectable, NgModule } from '@angular/core';

var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["INFO"] = 0] = "INFO";
    LogLevel[LogLevel["DEBUG"] = 1] = "DEBUG";
    LogLevel[LogLevel["WARNING"] = 2] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 3] = "ERROR";
})(LogLevel || (LogLevel = {}));
class AbstractNgxFancyLoggerService {
}
class LoggerConfig {
    constructor() {
        this.showTime = true;
        this.logLevel = LogLevel.INFO;
        this.levelColor = {};
    }
}
const DEFAULT_LEVEL_COLORS = {
    [LogLevel.INFO]: 'steelblue',
    [LogLevel.DEBUG]: 'black',
    [LogLevel.WARNING]: 'orange',
    [LogLevel.ERROR]: 'red'
};
let NgxFancyLoggerService = class NgxFancyLoggerService {
    constructor(loggerConfig) {
        this.loggerConfig = loggerConfig;
        this.DEFAULT_CONFIG = new LoggerConfig();
        this.showTime = () => {
            return this.config.showTime ? ` > ${new Date().toLocaleString()}` : '';
        };
        this.getStyles = (level) => `color:white;
                                            background-color:${this.config.levelColor[level] || DEFAULT_LEVEL_COLORS[level]};
                                            padding: 0px 2px;
                                            border-radius: 2px`;
        this.config = Object.assign(Object.assign({}, this.DEFAULT_CONFIG), loggerConfig);
    }
    info(...args) {
        this.log(LogLevel.INFO, 'log', args);
    }
    debug(...args) {
        this.log(LogLevel.DEBUG, 'log', args);
    }
    warning(...args) {
        this.log(LogLevel.WARNING, 'warn', args);
    }
    error(...args) {
        this.log(LogLevel.ERROR, 'error', args);
    }
    log(level, method, ...args) {
        if (level < this.config.logLevel) {
            return;
        }
        console[method](`%c${LogLevel[level]}${this.showTime()}`, this.getStyles(level), ...args);
    }
};
NgxFancyLoggerService.ctorParameters = () => [
    { type: LoggerConfig, decorators: [{ type: Optional }] }
];
NgxFancyLoggerService = __decorate([
    Injectable(),
    __param(0, Optional())
], NgxFancyLoggerService);

var NgxFancyLoggerModule_1;
let NgxFancyLoggerModule = NgxFancyLoggerModule_1 = class NgxFancyLoggerModule {
    static forRoot(config) {
        return {
            ngModule: NgxFancyLoggerModule_1,
            providers: [
                { provide: LoggerConfig, useValue: config || {} },
                NgxFancyLoggerService
            ]
        };
    }
};
NgxFancyLoggerModule = NgxFancyLoggerModule_1 = __decorate([
    NgModule({
        imports: [],
        providers: [NgxFancyLoggerService]
    })
], NgxFancyLoggerModule);

/*
 * Public API Surface of ngx-fancy-logger
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AbstractNgxFancyLoggerService, LogLevel, LoggerConfig, NgxFancyLoggerModule, NgxFancyLoggerService };
//# sourceMappingURL=ngx-fancy-logger.js.map
